/*
 * Copyright 2023, Rainer Noack, Frankfurt am Main, Germany.
 *
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. *
 */
package com.enitsys.sqltools;
import java.io.*;

public class ModifiablePrintWriter extends PrintWriter {
    private final String lineSeparatorOverride;
    private final boolean autoFlush;
    public ModifiablePrintWriter(Writer out, String lineSeparatorOverride) {
        super(out);
        this.lineSeparatorOverride = lineSeparatorOverride;
        this.autoFlush =false;
    }

    public ModifiablePrintWriter(Writer out, boolean autoFlush, String lineSeparatorOverride) {
        super(out, autoFlush);
        this.lineSeparatorOverride = lineSeparatorOverride;
        this.autoFlush =autoFlush;
    }

    public ModifiablePrintWriter(OutputStream out, String lineSeparatorOverride) {
        super(out);
        this.lineSeparatorOverride = lineSeparatorOverride;
        this.autoFlush =false;
    }

    public ModifiablePrintWriter(OutputStream out, boolean autoFlush, String lineSeparatorOverride) {
        super(out, autoFlush);
        this.lineSeparatorOverride = lineSeparatorOverride;
        this.autoFlush =autoFlush;
    }

    public ModifiablePrintWriter(String fileName, String lineSeparatorOverride) throws FileNotFoundException {
        super(fileName);
        this.lineSeparatorOverride = lineSeparatorOverride;
        this.autoFlush =false;
    }

    public ModifiablePrintWriter(String fileName, String csn, String lineSeparatorOverride) throws FileNotFoundException, UnsupportedEncodingException {
        super(fileName, csn);
        this.lineSeparatorOverride = lineSeparatorOverride;
        this.autoFlush =false;
    }

    public ModifiablePrintWriter(File file, String lineSeparatorOverride) throws FileNotFoundException {
        super(file);
        this.lineSeparatorOverride = lineSeparatorOverride;
        this.autoFlush =false;
    }

    public ModifiablePrintWriter(File file, String csn, String lineSeparatorOverride) throws FileNotFoundException, UnsupportedEncodingException {
        super(file, csn);
        this.lineSeparatorOverride = lineSeparatorOverride;
        this.autoFlush =false;
    }

    private void newLineOverride() {
        synchronized (lock) {
            write(lineSeparatorOverride);
            if (autoFlush)
                flush();
        }
    }

    @Override
    public void println() {
        if(lineSeparatorOverride ==null)
            super.println();
        else
            newLineOverride();
    }
}