/*
 * Copyright 2023, Rainer Noack, Frankfurt am Main, Germany.
 *
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. *
 */
package com.enitsys.sqltools;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStream;
import java.io.PrintWriter;
import java.io.Reader;

final class StreamRedirect implements Runnable {
    private final Reader reader;
    private final OutputStream redirect;

    StreamRedirect(Reader reader, OutputStream redirect)   {
        this.reader = reader;
        this.redirect = redirect;
    }
    StreamRedirect(InputStream inputStream, OutputStream redirect)   {
        this(new InputStreamReader(inputStream), redirect);
    }
    StreamRedirect(Reader reader)  {
        this(reader, null);
    }
    StreamRedirect(InputStream inputStream)  {
        this(inputStream, null);
    }

    public void run() {
        if (redirect == null)
            try {
                while (reader.read() != -1);
            } catch (IOException e) {
                e.printStackTrace();
            }
        else {
            try {
                PrintWriter printWriter = new PrintWriter(redirect);
                @SuppressWarnings("resource")
				BufferedReader bufferedReader=(reader instanceof BufferedReader)?(BufferedReader)reader:new BufferedReader(reader);
                for (String line = bufferedReader.readLine(); line != null; line = bufferedReader.readLine())
                    printWriter.println(line);
                printWriter.flush();
            } catch (IOException e) {
                e.printStackTrace();
            }
        }
    }
}